%  Copyright 2010 Carlos Gonzalez-Aguado
%
%  This file is part of the SAMPLE CODE for the following paper:
%  Bruche, M., Gonzalez-Aguado, C. "Recovery Rates, Default Probabilities, and the Credit Cycle"
%  Journal of Banking and Finance 34(4), 2010, 713-723.
%  
%  SAMPLE CODE is free software: you can redistribute it and/or modify it under
%  the terms of the GNU General Public License as published by the Free
%  Software Foundation, either version 3 of the License, or (at your option)
%  any later version.
%  
%  SAMPLE CODE is distributed in the hope that it will be useful, but WITHOUT
%  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
%  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
%  more details.
%  
%  You should have received a copy of the GNU General Public License along with
%  SAMPLE CODE.  If not, see <http://www.gnu.org/licenses/>.


% This script prepares the data to be used in the rest of the program

% Global variables
global rr sen event year evyear mul fstobs secobs n m t w total dsen groups mul

% RECOVERY RATES DATA
% Load data on recoveries from 'rr_data.mat'. 
load 'rr_data.mat';

%This file contains a matrix with N rows and 8 columns. Each row correspond to a defaulted bond, while the columns are as follows: bond identifier, default event identifier (different bonds may correspond to the same company, so to the same default event), name of the company that issued the bond, seniority, recovery rate, default year, industry, and a dummy indicating whether the observation corresponds to a firm with more than one bond defaulted. 
nbonds = size(data,1);
for i = nbonds:-1:2                      % This loop deletes multiple observations, we just keep the most senior one.
    if (data(i,2) == data(i-1,2))
        data(i,:) = [];
    end
end
event = data(:,2);
sen = data(:,4);
rr = data(:,5);    % With real data, you could re-scale recoveries here in order to have all of them lying between zero and one. 
year = data(:,6);
ind = data(:,7);
mul = data(:,8);

n = size(data,1);
t = year(n) - year(1) + 1;
n_obs = linspace(1,n,n)';

rrdat = [n_obs, event, sen, rr, year, mul];   % This is the final matrix with recoveries we are going to use in the program
save rr_data.txt rrdat -ascii
clear data;

% DEFAULT RATES DATA
% Load data on default rates from 'defrate.txt'.
w = zeros(t,1);
for i = 1:t
    w(i) = sum(year==i+1980);
end
load 'defrate.mat';
%dr = defrate(2:26,2)/100;
total = round(w./defrates);

% MACRO DATA
% Load macro data from 'macro_data.mat'.
load 'macro_data.mat';
% There aer six variables: GDP, unemployment, investment, SP500, VIX, and corporate spread. 
% gdp = data(:,2)/100;
% unemp = data(:,3)/100;
% invest = data(:,4)/100;
% sp500 = data(:,5)/100;
% vola = data(:,8);
% spread = data(:,9);


% Macro data has dimension T-times-1. Now, we expand this dimension and assing the macro observation for each recovery. 
% gdp_rr = zeros(n,1);
% for i = 1:n
%     gdp_rr(i) = gdp(year(i) - 1980);
% end
% unemp_rr = zeros(n,1);
% for i = 1:n
%     unemp_rr(i) = unemp(year(i) - 1980);
% end
% invest_rr = zeros(n,1);
% for i = 1:n
%     invest_rr(i) = invest(year(i) - 1980);
% end
% sp500_rr = zeros(n,1);
% for i = 1:n
%     sp500_rr(i) = sp500(year(i) - 1980);
% end
% vola_rr = zeros(n,1);
% for i = 1:n
%     vola_rr(i) = vola(year(i) - 1980);
% end
% spread_rr = zeros(n,1);
% for i = 1:n
%     spread_rr(i) = spread(year(i) - 1980);
% end
for i = 1:n
    macro_rr(i) = macro(year(i) - 1980);
end

% DUMMIES FOR SENIORITY
dsen = zeros(n,5);
for i = 1:5
    dsen(:,i) = (sen == i);
end

% GROUPS OF INDUSTRIES
groups = zeros(n,3);
groups(:,1) = (ind==4 | ind==5 | ind==10 | ind==11);
groups(:,2) = (ind==2 | ind==3 | ind==6 | ind==12);
groups(:,3) = (ind==1 | ind==7 | ind==8 | ind==9);










