%  Copyright 2010 Carlos Gonzalez-Aguado
%
%  This file is part of the SAMPLE CODE for the following paper:
%  Bruche, M., Gonzalez-Aguado, C. "Recovery Rates, Default Probabilities, and the Credit Cycle"
%  Journal of Banking and Finance 34(4), 2010, 713-723.
%  
%  SAMPLE CODE is free software: you can redistribute it and/or modify it under
%  the terms of the GNU General Public License as published by the Free
%  Software Foundation, either version 3 of the License, or (at your option)
%  any later version.
%  
%  SAMPLE CODE is distributed in the hope that it will be useful, but WITHOUT
%  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
%  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
%  more details.
%  
%  You should have received a copy of the GNU General Public License along with
%  SAMPLE CODE.  If not, see <http://www.gnu.org/licenses/>.


% This routine uses the variables included in the model to construct the recovery rates data matrix.

% Declare global variables
global rr_macro macro_var_rr rr_pars rr_mat1 rr_mat0 rr_mat groups dsen mul basic

% The minimum matrix is the following
basic = [ones(n,1) dsen(:,2:5) mul.*dsen(:,1) mul.*dsen(:,2) mul.*dsen(:,3)];

% If latent variable is included, we will create two matrices, rr_mat1 and rr_mat0. Otherwise, only rr_mat will be created. 
if rr_cycle
    rr_mat1 = [basic basic];
    rr_mat0 = [basic zeros(n,size(basic,2))];
else
    rr_mat = basic;
end

% If macro variables are included, some additional columns have to be added. 
if rr_macro
    if rr_cycle
        rr_mat1 = [rr_mat1 macro_var_rr mul.*macro_var_rr];
        rr_mat0 = [rr_mat0 macro_var_rr mul.*macro_var_rr];
    else
        rr_mat = [rr_mat macro_var_rr mul.*macro_var_rr];
    end
end

% If industry variables are included, some additional columns have to be added. 
if rr_ind
    if rr_cycle
        rr_mat1 = [rr_mat1 groups(:,2:3)];
        rr_mat0 = [rr_mat0 groups(:,2:3)];
    else
        rr_mat = [rr_mat groups(:,2:3)];
    end
end

% Calculate the number of parameters for recoveries
if rr_cycle
    rr_pars = size(rr_mat1,2);
else
    rr_pars = size(rr_mat,2);
end
