%  Copyright 2010 Carlos Gonzalez-Aguado
%
%  This file is part of the SAMPLE CODE for the following paper:
%  Bruche, M., Gonzalez-Aguado, C. "Recovery Rates, Default Probabilities, and the Credit Cycle"
%  Journal of Banking and Finance 34(4), 2010, 713-723.
%  
%  SAMPLE CODE is free software: you can redistribute it and/or modify it under
%  the terms of the GNU General Public License as published by the Free
%  Software Foundation, either version 3 of the License, or (at your option)
%  any later version.
%  
%  SAMPLE CODE is distributed in the hope that it will be useful, but WITHOUT
%  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
%  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
%  more details.
%  
%  You should have received a copy of the GNU General Public License along with
%  SAMPLE CODE.  If not, see <http://www.gnu.org/licenses/>.


% This function is the one that obtains the likelihood for each combination of latent variables.

function f = pre_lik(x,dr_m,rr_m)

% Declare global variables
global pars rr w total n t year l

% Parameters
l = 1 ./ (1 + exp(dr_m * x(pars(1,1):pars(1,2))));
a = exp(rr_m * x(pars(2,1):pars(2,2)));
b = exp(rr_m * x(pars(3,1):pars(3,2)));

% Densities
pdfs = betapdf(rr,a,b);

% Densities per period
t_pdf = zeros(t,1);
for i = 1:t
    t_pdf(i) = prod(pdfs(year == i + 1980));
end

% Default rates densities
d = zeros(t,1);
d = binopdf(w,total,l);

% Joint density per period
f = d .* t_pdf;

            
